@@ -21,14 +21,14 @@ from pathlib import Path
 from subprocess import Popen, PIPE, TimeoutExpired, run as srun
 from flask import abort, make_response, request
 import filelock
-import pdb
+import sys
 
 # from .logdict import logdict
 # '/var/log/pns-server.log'
 # logdict['handlers']['file']['filename'] = '/tmp/server.log'
 
 
-from .server_skeleton import setuplogging, checkpath, pc, Classes, app, auth, APIs
+from .server_skeleton import setuplogging, checkpath, pc, Classes, app, auth, APIs, gid, getUidGid
 
 logging = setuplogging()
 logger = logging.getLogger(__name__)
@@ -37,6 +37,17 @@ logger.setLevel(pc['logginglevel'])
 logger.debug('logging level %d' % (logger.getEffectiveLevel()))
 
 
+@app.before_first_request
+def init_pns_module():
+    global pc, gid
+    ptsuid, ptsgid = getUidGid(pc['ptsuser'])
+    sgroup = os.getgrouplist(pc['serveruser'], gid)
+    if ptsgid not in sgroup:
+        logger.error('ptsuser %s must be in the group of serveruser %s %s.' %
+                     (pc['ptsuser'], pc['serveruser'], str(sgroup)))
+        sys.exit(2)
+
+
 def _execute(cmd, input=None, timeout=10):
     """ Executes a command on the server host in the pnshome directory and returns run status. Default imeout is 10sec. Run as user set byas.
     returns {return code, msg}
