@@ -5,6 +5,7 @@ from fdi.pns.pnsconfig import pnsconfig as pc
 from fdi.utils.options import opt
 from fdi.utils.getconfig import getConfig
 
+from waitress import serve
 #sys.path.insert(0, abspath(join(join(dirname(__file__), '..'), '..')))
 
 # print(sys.path)
@@ -47,7 +48,8 @@ if __name__ == '__main__':
             'default': node['port'], 'description':'port number'},
         {'long': 'server=', 'char': 's',
             'default': 'pns', 'description': 'server type: pns or httppool_server'},
-
+        {'long': 'wsgi', 'char': 'w', 'default': False,
+            'description': 'run a WSGI server.'},
     ]
 
     out = opt(ops)
@@ -56,6 +58,7 @@ if __name__ == '__main__':
         n = out[j]['long'].strip('=')
         node[n] = out[j]['result']
     servertype = out[6]['result']
+    wsgi = out[7]['result']
 
     if verbose:
         logger.setLevel(logging.DEBUG)
@@ -78,5 +81,8 @@ if __name__ == '__main__':
         logger.error('Unknown server %s' % servertype)
         sys.exit(-1)
 
-    app.run(host=node['host'], port=node['port'],
-            threaded=True, debug=verbose, processes=1, use_reloader=False)
+    if wsgi:
+        serve(app, url_scheme='https', host=node['host'], port=node['port'])
+    else:
+        app.run(host=node['host'], port=node['port'],
+                threaded=True, debug=verbose, processes=1, use_reloader=False)
