@@ -2,9 +2,9 @@
 
 from ..dataset.classes import Classes
 from ..utils.getconfig import getConfig
+from ..utils.common import trbk
 
 from .pnsconfig import pnsconfig as pc
-import datetime
 import time
 import sys
 import pwd
@@ -15,7 +15,6 @@ import types
 from subprocess import Popen, PIPE, TimeoutExpired, run as srun
 from flask import Flask, jsonify, abort, make_response, request, url_for
 from flask_httpauth import HTTPBasicAuth
-import filelock
 
 # from .logdict import logdict
 # '/var/log/pns-server.log'
@@ -39,10 +38,6 @@ def setuplogging():
 logging = setuplogging()
 logger = logging.getLogger(__name__)
 
-pc.update(getConfig())
-logger.setLevel(pc['logginglevel'])
-logger.debug('logging level %d' % (logger.getEffectiveLevel()))
-
 
 def getUidGid(username):
     """ returns the UID and GID of the named user.
@@ -69,24 +64,22 @@ def getUidGid(username):
 
 app = Flask(__name__)
 auth = HTTPBasicAuth()
+gid = -1
 
 
 @app.before_first_request
 def init_skeleton_module():
-    global pc
+    global pc, gid, logger
+    pc.update(getConfig())
+    logger.setLevel(pc['logginglevel'])
+    logger.debug('logging level %d' % (logger.getEffectiveLevel()))
+
     # effective group of current process
     uid, gid = getUidGid(pc['serveruser'])
-    # logger.info
-    print("Set process to %s's uid %d and gid %d..." %
-          (pc['serveruser'], uid, gid))
-    os.setuid(uid)
-    os.setgid(gid)
-
-    ptsuid, ptsgid = getUidGid(pc['ptsuser'])
-    if gid not in os.getgrouplist(pc['ptsuser'], ptsgid):
-        logger.error('ptsuser %s must be in the group of serveruser %s.' %
-                     (pc['ptsuser'], pc['serveruser']))
-        sys.exit(2)
+    logger.info("Serveruser %s's uid %d and gid %d..." %
+                (pc['serveruser'], uid, gid))
+    # os.setuid(uid)
+    # os.setgid(gid)
 
     # setup user class mapping
     clp = pc['userclasses']
